# FitTrackee
**A simple self-hosted workout/activity tracker.**  

[![PyPI version](https://img.shields.io/pypi/v/fittrackee.svg)](https://pypi.org/project/fittrackee/) 
[![Python Version](https://img.shields.io/badge/python-3.8+-brightgreen.svg)](https://python.org)
[![Flask Version](https://img.shields.io/badge/flask-3.0-brightgreen.svg)](http://flask.pocoo.org/) 
[![code style: black](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black) 
[![type check: mypy](https://img.shields.io/badge/type%20check-mypy-blue)](http://mypy-lang.org/)  
[![Vue Version](https://img.shields.io/badge/vue-3.2-brightgreen.svg)](https://v3.vuejs.org/) 
[![Typescript Version](https://img.shields.io/npm/types/typescript)](https://www.typescriptlang.org/) 
[![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier)  
[![pipeline status](https://github.com/SamR1/FitTrackee/actions/workflows/.tests-python.yml/badge.svg)](https://github.com/SamR1/FitTrackee/actions/workflows/.tests-python.yml)
[![pipeline status](https://github.com/SamR1/FitTrackee/actions/workflows/.tests-javascript.yml/badge.svg)](https://github.com/SamR1/FitTrackee/actions/workflows/.tests-javascript.yml)
[![translation status](https://hosted.weblate.org/widgets/fittrackee/-/svg-badge.svg)](https://hosted.weblate.org/engage/fittrackee/)  

---

This web application allows you to track your outdoor activities (workouts) from gpx files and keep your data on your own server.  
No mobile app has been developed yet, but several existing mobile apps can store workouts data locally and export them into a gpx file.  
Examples for Android (non-exhaustive list):  
* [Runner Up](https://github.com/jonasoreland/runnerup) (GPL v3)  
* [OpenTracks](https://github.com/OpenTracksApp/OpenTracks) (Apache License)  
* [FitoTrack](https://codeberg.org/jannis/FitoTrack) (GPL v3)  

Maps are displayed using [Open Street Map](https://www.openstreetmap.org).  
It is also possible to add a workout without a gpx file.

**Still under heavy development (some features may be unstable).**  
(see [issues](https://github.com/SamR1/FitTrackee/issues) and [documentation](https://samr1.github.io/FitTrackee) for more information)  

![FitTrackee Dashboard Screenshot](https://samr1.github.io/FitTrackee/en/_images/fittrackee_screenshot-01.png)
